@@ -7,18 +7,14 @@ s-expressions are inspired from Lisp.
 import functools as ft
 from dataclasses import dataclass
 from typing import Callable, Generic, Tuple, TypeVar
-import operator
-from typing_extensions import reveal_type
 
 # Imports from third-party modules.
 from colorama import Fore, Style
 from loguru import logger
 
-from normal_form.cnf import Cnf
-
 # Type variables and aliases
 Src = TypeVar('Src', covariant=True)
-Trgt = TypeVar('Trgt', contravariant=True)
+Trgt = TypeVar('Trgt', covariant=True)
 
 
 @dataclass
